@@ -1,4 +1,5 @@
-const HostedGit = require('../index')
+/* eslint-disable max-len */
+const HostedGit = require('..')
 const t = require('tap')
 
 const invalid = [
@@ -18,12 +19,12 @@ const invalid = [
   // missing path
   'git+ssh://git@github.com:',
   // a deep url to something we don't know
-  'https://github.com/foo/bar/issues'
+  'https://github.com/foo/bar/issues',
 ]
 
 // assigning the constructor here is hacky, but the only way to make assertions that compare
 // a subset of properties to a found object pass as you would expect
-const GitHost = require('../git-host')
+const GitHost = require('../lib/git-host')
 const defaults = { constructor: GitHost, type: 'github', user: 'foo', project: 'bar' }
 const valid = {
   // extreme shorthand
@@ -182,7 +183,7 @@ const valid = {
   'https://www.github.com/foo/bar': { ...defaults, default: 'https' },
   'foo/bar#branch with space': { ...defaults, default: 'shortcut', committish: 'branch with space' },
   'https://github.com/foo/bar/tree/branch': { ...defaults, default: 'https', committish: 'branch' },
-  'user..blerg--/..foo-js# . . . . . some . tags / / /': { ...defaults, default: 'shortcut', user: 'user..blerg--', project: '..foo-js', committish: ' . . . . . some . tags / / /' }
+  'user..blerg--/..foo-js# . . . . . some . tags / / /': { ...defaults, default: 'shortcut', user: 'user..blerg--', project: '..foo-js', committish: ' . . . . . some . tags / / /' },
 }
 
 t.test('valid urls parse properly', t => {
@@ -229,6 +230,9 @@ t.test('string methods populate correctly', t => {
   t.equal(parsed.hash(), '', 'hash() returns empty string when committish is unset')
   t.equal(parsed.ssh(), 'git@github.com:foo/bar.git')
   t.equal(parsed.sshurl(), 'git+ssh://git@github.com/foo/bar.git')
+  t.equal(parsed.edit(), 'https://github.com/foo/bar')
+  t.equal(parsed.edit('/lib/index.js'), 'https://github.com/foo/bar/edit/master/lib/index.js')
+  t.equal(parsed.edit('/lib/index.js', { committish: 'docs' }), 'https://github.com/foo/bar/edit/docs/lib/index.js')
   t.equal(parsed.browse(), 'https://github.com/foo/bar')
   t.equal(parsed.browse('/lib/index.js'), 'https://github.com/foo/bar/tree/master/lib/index.js')
   t.equal(parsed.browse('/lib/index.js', 'L100'), 'https://github.com/foo/bar/tree/master/lib/index.js#l100')
