@@ -1,5 +1,6 @@
+/* eslint-disable max-len */
 'use strict'
-const HostedGit = require('../index')
+const HostedGit = require('..')
 const t = require('tap')
 
 const invalid = [
@@ -9,12 +10,12 @@ const invalid = [
   'https://gitlab.com/foo',
   // tarball, this should not parse so that it can be used for pacote's remote fetcher
   'https://gitlab.com/foo/bar/repository/archive.tar.gz',
-  'https://gitlab.com/foo/bar/repository/archive.tar.gz?ref=49b393e2ded775f2df36ef2ffcb61b0359c194c9'
+  'https://gitlab.com/foo/bar/repository/archive.tar.gz?ref=49b393e2ded775f2df36ef2ffcb61b0359c194c9',
 ]
 
 // assigning the constructor here is hacky, but the only way to make assertions that compare
 // a subset of properties to a found object pass as you would expect
-const GitHost = require('../git-host')
+const GitHost = require('../lib/git-host')
 const defaults = { constructor: GitHost, type: 'gitlab', user: 'foo', project: 'bar' }
 const subgroup = { constructor: GitHost, type: 'gitlab', user: 'foo/bar', project: 'baz' }
 const valid = {
@@ -247,7 +248,7 @@ const valid = {
   'https://user:password@gitlab.com/foo/bar/baz.git': { ...subgroup, default: 'https', auth: 'user:password' },
   'https://user:password@gitlab.com/foo/bar/baz.git#branch': { ...subgroup, default: 'https', auth: 'user:password', committish: 'branch' },
   'https://:password@gitlab.com/foo/bar/baz.git': { ...subgroup, default: 'https', auth: ':password' },
-  'https://:password@gitlab.com/foo/bar/baz.git#branch': { ...subgroup, default: 'https', auth: ':password', committish: 'branch' }
+  'https://:password@gitlab.com/foo/bar/baz.git#branch': { ...subgroup, default: 'https', auth: ':password', committish: 'branch' },
 }
 
 t.test('valid urls parse properly', t => {
@@ -286,6 +287,8 @@ t.test('string methods populate correctly', t => {
   t.equal(parsed.hash(), '', 'hash() returns empty string when committish is unset')
   t.equal(parsed.ssh(), 'git@gitlab.com:foo/bar.git')
   t.equal(parsed.sshurl(), 'git+ssh://git@gitlab.com/foo/bar.git')
+  t.equal(parsed.edit(), 'https://gitlab.com/foo/bar')
+  t.equal(parsed.edit('/lib/index.js'), 'https://gitlab.com/foo/bar/-/edit/master/lib/index.js')
   t.equal(parsed.browse(), 'https://gitlab.com/foo/bar')
   t.equal(parsed.browse('/lib/index.js'), 'https://gitlab.com/foo/bar/tree/master/lib/index.js')
   t.equal(parsed.browse('/lib/index.js', 'L100'), 'https://gitlab.com/foo/bar/tree/master/lib/index.js#l100')
